import React from 'react';
import { Link } from 'react-router';
import { connect } from 'react-redux';
import classnames from 'classnames';
import Footer from './Footer';
import Navbar from './Navbar';
import LaunchButton from './LaunchButton';

class Pricing extends React.Component {
  constructor() {
    super();
    this.state = {
      showMonthly: true,
      basicOpen: false,
      essentialOpen: false,
      premiumOpen: false
    };
    this.prices = {
      basic: {
        monthly: 99,
        annual: 990
      },
      essential: {
        monthly: 199,
        annual: 1990
      },
      premium: {
        monthly: 299,
        annual: 2990
      }
    };
  }

  togglePricing(e) {
    this.setState({showMonthly: !this.state.showMonthly});
  }

  packageClasses(pkg) {
    return this.state[pkg + 'Open'] ? 'package package-expanded' : 'package';
  }

  render() {
    const { showMonthly, basicOpen, essentialOpen, premiumOpen } = this.state;
    const interval = showMonthly ? 'monthly' : 'annual';
    const intervalSm = showMonthly ? 'mo' : 'yr';
    const toggleClasses = classnames('change-pricing-switch-toggle', {[interval]: true});

    return (
      <div id="home" className="with-navbar not-front page-pricing no-sidebars">
        <Navbar page="pricing" />
        <header className="hero">
          <section className="responsive">
            <h1>
              Find your perfect <strong>pricing plan</strong>
            </h1>
            <h2>
              Start your <strong>free 14-day trial</strong> and discover why traders everywhere use Pro every day.
            </h2>
          </section>
        </header>
        <main role="main">
          <div className="change-pricing">
            <section className="responsive">
              <h1>View prices for:</h1>
              <div className="change-pricing-switch" onClick={(e) => this.togglePricing(e)}>
                <label htmlFor="monthly">Monthly</label>
                <label htmlFor="yearly">Annual</label>
                <span className={toggleClasses}></span>
              </div>
            </section>
          </div>
          <div className="products">
            <section className="responsive">
              <div className={this.packageClasses('basic')} onClick={(() => this.setState({basicOpen: !basicOpen}))}>
                <div className="package-box">
                  <div className="package-box-header">
                    <div className="package-box-header-name">Basic</div>
                    <div className="package-box-header-price">
                      ${this.prices.basic[interval]}
                      <span className="interval">/{intervalSm}</span>
                    </div>
                  </div>
                  <div className="package-box-subheader">
                    <div className="package-box-subheader-occurrence">&nbsp;</div>
                  </div>
                  <Link to={'/checkout/basic/' + interval + '/'} className="button button-transparent button-plan">Start my 14-day trial</Link>
                </div>
                <div className="package-features">
                  <ul>
                    <li>Watchlist Alerts</li>
                    <li>Security Snapshot with Key Stats</li>
                    <li>Newsfeed Access (does not include SEC or PR feeds)</li>
                  </ul>
                  <Link to={'/checkout/basic/' + interval + '/'} className="button button-green button-plan">Start my 14-day trial</Link>
                </div>
              </div>
              <div className={this.packageClasses('essential')} onClick={(() => this.setState({essentialOpen: !essentialOpen}))}>
                <div className="package-box package-box-popular">
                  <div className="package-box-header">
                    <div className="package-box-header-name">Essential</div>
                    <div className="package-box-header-price">
                      ${this.prices.essential[interval]}
                      <span className="interval">/{intervalSm}</span>
                    </div>
                  </div>
                  <div className="package-box-subheader">
                    <div className="package-box-subheader-occurrence">&nbsp;</div>
                  </div>
                  <Link to={'/checkout/essential/' + interval + '/'} className="button button-green">Start my 14-day trial</Link>
                </div>
                <div className="package-features">
                  <ul>
                    <li>Watchlist Alerts</li>
                    <li>Security Snapshot with Key Stats</li>
                    <li className="package-features-exclusive">Full Newsfeed Access</li>
                    <li className="package-features-exclusive">Audio Squawk</li>
                    <li className="package-features-exclusive">Calendar Suite</li>
                  </ul>
                  <Link to={'/checkout/essential/' + interval + '/'} className="button button-green">Start my 14-day trial</Link>
                </div>
              </div>
              <div className={this.packageClasses('premium')} onClick={(() => this.setState({premiumOpen: !premiumOpen}))}>
                <div className="package-box">
                  <div className="package-box-header">
                    <div className="package-box-header-name">Premium</div>
                    <div className="package-box-header-price">
                      ${this.prices.premium[interval]}
                      <span className="interval">/{intervalSm}</span>
                    </div>
                  </div>
                  <div className="package-box-subheader">
                    <div className="package-box-subheader-occurrence">&nbsp;</div>
                  </div>
                  <Link to={'/checkout/premium/' + interval + '/'} className="button button-transparent button-plan">Start my 14-day trial</Link>
                </div>
                <div className="package-features">
                  <ul>
                    <li>Watchlist Alerts</li>
                    <li>Security Snapshot with Key Stats</li>
                    <li>Full Newsfeed Access</li>
                    <li>Audio Squawk</li>
                    <li>Calendar Suite</li>
                    <li className="package-features-exclusive">Chat with the Newsdesk</li>
                    <li className="package-features-exclusive">Sentiment Indicators</li>
                    <li className="package-features-exclusive">Personal Account Manager</li>
                  </ul>
                  <Link to={'/checkout/premium/' + interval + '/'} className="button button-green button-plan">Start my 14-day trial</Link>
                </div>
              </div>
              <div className="package">
                <div className="package-box package-box-enterprise">
                  <div className="package-box-header">
                    <div className="package-box-header-name">Licensing</div>
                    <div className="package-box-header-price">
                      All Content and Data can be licensed via APIs for Trading Platforms, Websites and Quant Trading.
                    </div>
                  </div>
                  <a href="http://cloud.benzinga.com" className="button button-transparent">Visit Benzinga Cloud</a>
                </div>
              </div>
              <p className="callus">
                Interested in group licensing or have other questions? Call us at <a href="tel:+8774409464">1-877-440-9464</a>
              </p>
            </section>
          </div>
          <div className="features">
            <section className="responsive">
              <h1>Benzinga Pro gives you...</h1>
              <ul>
                <li>
                  <h2>Full Newsfeed Access</h2>
                  <p>Including options alerts, price/volume movers, rumors, exclusive executive, analyst, floor-trader commentary, trading ideas, historical context -- all in real-time!</p>
                </li>
                <li>
                  <h2>Ticker Search</h2>
                  <p>Quickly find news, earnings, ratings, and our other data sets on a particular security.</p>
                </li>
                <li>
                  <h2>Full Calendar Suite</h2>
                  <p>Including earnings, guidance, economic data, ratings and many more!</p>
                </li>
                <li>
                  <h2>Previews / Commentary</h2>
                  <p>Benzinga Pro isn't just an aggregated feed. Our analysts write original pieces, like earnings previews and commentary on analyst ratings, to help you sift through the market noise.</p>
                </li>
              </ul>
              <ul>
                <li>
                  <h2>Trading Ideas</h2>
                  <p>In addition to delevering the fastest, most accurate news, Benzinga also helps you trade off that news by providing trading ideas from our analysts.</p>
                </li>
                <li>
                  <h2>Simple Intuitive Interface</h2>
                  <p>Benzinga Pro's minimal interface makes news and data easy to digest.</p>
                </li>
                <li>
                  <h2>Customization / Watchlists</h2>
                  <p>Choose which channels you see in your feed and from which stocks to streamline your trading.</p>
                </li>
                <li>
                  <h2>Realtime Speed</h2>
                  <p>Our analysts are lightning fast, often beating the industry giants. Not only is the news fast, but often times more accurate.</p>
                </li>
              </ul>
              <ul>
                <li>
                  <h2>Audio Squawk</h2>
                  <p>Don't have space to fit a newsfeed on your desktop? Let the Benzinga Pro analysts read the news outloud to you!</p>
                </li>
                <li>
                  <h2>Sentiment Indicators</h2>
                  <p>Benzinga Pro analysts use historical context related to a news items in order to try to help anticipate the direction or degree of a price move.</p>
                </li>
                <li>
                  <h2>Chat With Newsdesk</h2>
                  <p>Have your very own newsdesk at your disposal! If a stock is moving and the newsfeed does not suggest why, chat in and let the Newsdesk analysts attack! We will check for news, check the chart for any important technicals, and also contact industry-sources to get to the bottom of the action!</p>
                </li>
              </ul>
            </section>
          </div>
          <div className="questions">
            <section className="responsive">
              <h1>FAQ</h1>
              <ul>
                <li>
                  <h2>Why use Benzinga Pro?</h2>
                  <p>For the fastest real-time news feed, the most profitable trading ideas, and exclusive content.</p>
                </li>
                <li>
                  <h2>What can I find on Benzinga Pro?</h2>
                  <p>Benzinga Pro's features include: full news feed access, real time speed, comprehensive searching, previews/commentary, trading ideas, customization/watch lists, audio news, exclusive comments from corporate CEOs, the ability to chat with the news desk, and an all-new interface designed specifically for a seamless user experience.</p>
                </li>
                <li>
                  <h2>How are you different from other news sources like The Wall Street Journal, CNBC, or Bloomberg?</h2>
                  <p>Other news outlets focus on a wide variety of topics, Benzinga Pro is dedicated to serving you -- the trader. Serving your trading needs is our number-one goal.</p>
                </li>
              </ul>
              <ul>
                <li>
                  <h2>Why do you have three levels of membership?</h2>
                  <p>We understand that professional traders have different needs than a user relatively new to trading. With Benzinga Pro, we wanted to give our users as many options as possible, which is why we offer three levels of membership.</p>
                </li>
                <li>
                  <h2>Why do I have to enter my credit card information if the trial is free anyway?</h2>
                  <p>In order for us to process your subscription, we require that all users submit their credit card information, even during the free trial period. That way, those who wish to continue using Benzinga Pro beyond the trial period can do so without interruption.</p>
                </li>
                <li>
                  <h2>I'm getting errors while on the site. Can I talk to a real human being?</h2>
                  <p>Absolutely. Visit pro.benzinga.com and click on the "Chat Now!" button on the bottom right corner of the page. Alternatively, you can reach us by e-mail at support@benzingapro.com or call us at 1-877-440-9464.</p>
                </li>
              </ul>
            </section>
          </div>
        </main>
        <Footer />
      </div>
    );
  }
}

export default connect()(Pricing);
