jest.dontMock('../CVCInput');
jest.dontMock('../../utils');

import React from 'react';
import ReactDOM from 'react-dom';
import TestUtils from 'react-addons-test-utils';

const CVCInput = require('../CVCInput').default;
const callback = jest.genMockFn();

describe('CVCInput lifecycle tests', () => {
  let component;
  let input;

  beforeEach(() => {
    component = TestUtils.renderIntoDocument(<CVCInput onStateUpdate={callback}/>);
    input = component.refs.ccCVCInput;
  });

  it('renders properly on load', () => {
    // Should exist
    expect(input).toBeTruthy();
    // Should be empty
    expect(input.textContent).toBe('');
    // Should have an empty state
    expect(component.state.value).toBe('');
  });

  it('handles onInput properly', () => {
    // Set a new value
    input.value = '123';

    // Change it
    TestUtils.Simulate.input(input);

    // Check it
    expect(component.state.value).toBe('123');
  });

  it('calls props.onStateUpdate to change outer state', () => {
    // Set a new value
    input.value = '123';

    // Change it
    TestUtils.Simulate.input(input);

    // Check it
    expect(callback).toBeCalled();
  });

  it('handles onPaste properly', () => {
    component.reformatCVC = jest.genMockFn();

    // Set a new value
    input.value = '123';

    // Change it
    TestUtils.Simulate.paste(input);

    // Check it
    expect(component.reformatCVC).toBeCalled();
  });

  it('handles onKeyPress properly', () => {
    component.restrictCVC = jest.genMockFn();

    // Trigger
    TestUtils.Simulate.keyPress(input, {keyCode: 54});

    // Check it
    expect(component.restrictCVC).toBeCalled();
  });
});

describe('CVCInput formatter/validator tests', () => {
  let component;
  let input;

  beforeEach(() => {
    component = TestUtils.renderIntoDocument(<CVCInput onStateUpdate={callback}/>);
    input = component.refs.ccCVCInput;
  });

  it('ensures restrictCVC disallows letter input', () => {
    // Set up a dummy event
    const event = {
      keyCode: 65,
      which: 65,
      target: {value: ''},
      preventDefault: jest.genMockFn()
    };

    expect(component.restrictCVC(event)).toBeTruthy();
  });

  it('ensures restrictCVC restricts over 4 digit input', () => {
    // Set up a dummy event
    const event = {
      keyCode: 55,
      which: 55,
      target: {value: '12345'},
      preventDefault: jest.genMockFn()
    };

    const result = component.restrictCVC(event);
    expect(event.preventDefault).toBeCalled();
  });

  it('ensures restrictCVC restricts selected text', () => {
    // Dummy event
    const event = {
      keyCode: 53,
      which: 53,
      target: {value: '1234', selectionStart: 3, selectionEnd: 4},
      preventDefault: jest.genMockFn()
    };

    // We need to restrict this
    expect(component.restrictCVC(event)).toBeTruthy();
  });
});
