jest.dontMock('../ZipInput');
jest.dontMock('../../utils');

import React from 'react';
import ReactDOM from 'react-dom';
import TestUtils from 'react-addons-test-utils';

const ZipInput = require('../ZipInput').default;
const callback = jest.genMockFn();

describe('ZipInput lifecycle tests', () => {
  let component;
  let input;

  beforeEach(() => {
    component = TestUtils.renderIntoDocument(<ZipInput onStateUpdate={callback}/>);
    input = component.refs.ZipInput;
  });

  it('renders properly on load', () => {
    // Should exist
    expect(input).toBeTruthy();
    // Should be empty
    expect(input.textContent).toBe('');
    // Should have an empty state
    expect(component.state.value).toBe('');
  });

  it('handles onInput properly', () => {
    // Set a new value
    input.value = '90210';

    // Change it
    TestUtils.Simulate.input(input);

    // Check it
    expect(component.state.value).toBe('90210');
  });

  it('calls props.onStateUpdate to change outer state', () => {
    // Set a new value
    input.value = '90210';

    // Change it
    TestUtils.Simulate.input(input);

    // Check it
    expect(callback).toBeCalled();
  });

  it('handles onPaste properly', () => {
    component.reformatZip = jest.genMockFn();

    // Set a new value
    input.value = '90210';

    // Change it
    TestUtils.Simulate.paste(input);

    // Check it
    expect(component.reformatZip).toBeCalled();
  });

  it('handles onKeyPress properly', () => {
    component.restrictZip = jest.genMockFn();

    // Trigger
    TestUtils.Simulate.keyPress(input, {keyCode: 54});

    // Check it
    expect(component.restrictZip).toBeCalled();
  });
});

describe('ZipInput formatter/validator tests', () => {
  let component;
  let input;

  beforeEach(() => {
    component = TestUtils.renderIntoDocument(<ZipInput onStateUpdate={callback}/>);
    input = component.refs.ZipInput;
  });

  it('ensures restrictZip restricts over 12 digit input', () => {
    // Set up a dummy event
    const event = {
      keyCode: 55,
      which: 55,
      target: {value: '1234567891011'},
      preventDefault: jest.genMockFn()
    };

    const result = component.restrictZip(event);
    expect(event.preventDefault).toBeCalled();
  });
});
